[shill] Add wpa_supplicant API spec to shill. Also, change 'proxy' -> 'adaptor'

Add the XML description of the wpa_supplicant DBus API, so we can
generate client (proxy object) bindings for it.  to use these
bindings, #include "shill/supplicant_cli.h" and then inherit from the
appropriate class in the fi::w1::wpa_supplicant1 namespace.

For example, for the WPA supplicant "Network" interface:

class SupplicantNetworkProxy : public fi::w1::wpa_supplicant1::Network_proxy {
 public:
  SupplicantNetworkProxy() {}
  virtual ~SupplicantNetworkProxy() {}

  // All signal handlers are abstract in the base class; implement them all here
  virtual void PropertiesChanged(
      const std::map< std::string, ::DBus::Variant >& properties) {
    return;
  }

  // Methods are all implemented for you, as are accessors for properties.
};

BUG=chromium-os:15092
TEST=build

Change-Id: I55e42148bc64965317e7223c852707ed6359b0bc
Reviewed-on: http://gerrit.chromium.org/gerrit/572
Reviewed-by: Chris Masone <cmasone@chromium.org>
Tested-by: Chris Masone <cmasone@chromium.org>
diff --git a/control_interface.h b/control_interface.h
index 5871f2e..882291c 100644
--- a/control_interface.h
+++ b/control_interface.h
@@ -15,43 +15,43 @@
 
 using std::string;
 
-// This is the Inteface for "partner" objects which are in charge of
-// RPC to the various core classes.
-class ProxyInterface {
+// This is the Interface for "partner" objects which are in charge of
+// handling incoming RPCs to the various core classes.
+class AdaptorInterface {
  public:
   virtual void SetProperty(const string &key, const string &value) = 0;
   virtual const string *GetProperty(const string &key) = 0;
   virtual void ClearProperty(const string &key) = 0;
-  virtual ~ProxyInterface() {}
+  virtual ~AdaptorInterface() {}
 };
 
-// These are the functions that a Manager proxy must support
-class ManagerProxyInterface {
+// These are the functions that a Manager adaptor must support
+class ManagerAdaptorInterface {
  public:
   virtual void UpdateRunning() = 0;
-  virtual ~ManagerProxyInterface() {}
+  virtual ~ManagerAdaptorInterface() {}
 };
 
-// These are the functions that a Manager proxy must support
-class ServiceProxyInterface {
+// These are the functions that a Service adaptor must support
+class ServiceAdaptorInterface {
  public:
   virtual void UpdateConnected() = 0;
-  virtual ~ServiceProxyInterface() {}
+  virtual ~ServiceAdaptorInterface() {}
 };
 
-// These are the functions that a Manager proxy must support
-class DeviceProxyInterface {
+// These are the functions that a Device adaptor must support
+class DeviceAdaptorInterface {
  public:
   virtual void UpdateEnabled() = 0;
-  virtual ~DeviceProxyInterface() {}
+  virtual ~DeviceAdaptorInterface() {}
 };
 
 // This is the Interface for an object factory that creates proxy objects
 class ControlInterface {
  public:
-  virtual ManagerProxyInterface *CreateManagerProxy(Manager *manager) = 0;
-  virtual ServiceProxyInterface *CreateServiceProxy(Service *service) = 0;
-  virtual DeviceProxyInterface *CreateDeviceProxy(Device *device) = 0;
+  virtual ManagerAdaptorInterface *CreateManagerAdaptor(Manager *manager) = 0;
+  virtual ServiceAdaptorInterface *CreateServiceAdaptor(Service *service) = 0;
+  virtual DeviceAdaptorInterface *CreateDeviceAdaptor(Device *device) = 0;
   virtual ~ControlInterface() {}
 };
@@ -15,43 +15,43 @@
 };
 
-// This is the Interface for an object factory that creates proxy objects
+// This is the Interface for an object factory that creates adaptor objects
 class ControlInterface {
  public: